# Generated by roxygen2: do not edit by hand

export(CIs)
export(CVe)
export(FCs)
export(FLs)
export(NUs)
export(RFCs)
export(RIs)
export(Radial_plot)
export(URs)
export(URsum)
export(UVs)
export(ethnoChord)
export(ethno_alluvial)
export(ethno_bayes_consensus)
export(ethno_boot)
export(simple_UVs)
importFrom(circlize,chordDiagram)
importFrom(circlize,circos.text)
importFrom(circlize,get.cell.meta.data)
importFrom(cowplot,plot_grid)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,summarize)
importFrom(ggalluvial,StatStratum)
importFrom(ggalluvial,geom_alluvium)
importFrom(ggalluvial,geom_stratum)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_polar)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggproto)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme_minimal)
importFrom(ggridges,geom_density_ridges)
importFrom(ggridges,theme_ridges)
importFrom(grDevices,rainbow)
importFrom(graphics,strwidth)
importFrom(magrittr,"%>%")
importFrom(reshape2,melt)
importFrom(stats,aggregate)
importFrom(stats,complete.cases)
importFrom(stats,na.omit)
importFrom(stats,rexp)
